@@ -1,13 +1,12 @@
 package Dist::Zilla;
 {
-  $Dist::Zilla::VERSION = '4.300020';
+  $Dist::Zilla::VERSION = '5.008';
 }
 # ABSTRACT: distribution builder; installer not included!
 use Moose 0.92; # role composition fixes
 with 'Dist::Zilla::Role::ConfigDumper';
 
 use Moose::Autobox 0.09; # ->flatten
-use MooseX::LazyRequire;
 use MooseX::Types::Moose qw(ArrayRef Bool HashRef Object Str);
 use MooseX::Types::Perl qw(DistName LaxVersionStr);
 use MooseX::Types::Path::Class qw(Dir File);
@@ -15,9 +14,9 @@ use Moose::Util::TypeConstraints;
 
 use Dist::Zilla::Types qw(License);
 
-use Hash::Merge::Simple ();
 use Log::Dispatchouli 1.100712; # proxy_loggers, quiet_fatal
 use Path::Class;
+use Path::Tiny;
 use List::Util qw(first);
 use Software::License 0.101370; # meta2_name
 use String::RewritePrefix;
@@ -41,7 +40,8 @@ has chrome => (
 has name => (
   is   => 'ro',
   isa  => DistName,
-  lazy_required => 1,
+  lazy => 1,
+  builder => '_build_name',
 );
 
 
@@ -57,10 +57,26 @@ has version => (
   isa  => LaxVersionStr,
   lazy => 1,
   init_arg  => undef,
-  required  => 1,
   builder   => '_build_version',
 );
 
+sub _build_name {
+  my ($self) = @_;
+
+  my $name;
+  for my $plugin ($self->plugins_with(-NameProvider)->flatten) {
+    next unless defined(my $this_name = $plugin->provide_name);
+
+    $self->log_fatal('attempted to set name twice') if defined $name;
+
+    $name = $this_name;
+  }
+
+  $self->log_fatal('no name was ever set') unless defined $name;
+
+  $name;
+}
+
 sub _build_version {
   my ($self) = @_;
 
@@ -84,7 +100,6 @@ has abstract => (
   is   => 'rw',
   isa  => 'Str',
   lazy => 1,
-  required => 1,
   default  => sub {
     my ($self) = @_;
 
@@ -120,7 +135,6 @@ has main_module => (
   isa  => 'Dist::Zilla::Role::File',
   lazy => 1,
   init_arg => undef,
-  required => 1,
   default  => sub {
 
     my ($self) = @_;
@@ -189,6 +203,24 @@ sub _build_license {
   my $copyright_holder = $self->_copyright_holder;
   my $copyright_year   = $self->_copyright_year;
 
+  my $provided_license;
+
+  for my $plugin ($self->plugins_with(-LicenseProvider)->flatten) {
+    my $this_license = $plugin->provide_license({
+      copyright_holder => $copyright_holder,
+      copyright_year   => $copyright_year,
+    });
+
+    next unless defined $this_license;
+
+    $self->log_fatal('attempted to set license twice')
+      if defined $provided_license;
+
+    $provided_license = $this_license;
+  }
+
+  return $provided_license if defined $provided_license;
+
   if ($license_class) {
     $license_class = String::RewritePrefix->rewrite(
       {
@@ -206,7 +238,8 @@ sub _build_license {
     if (@guess != 1) {
       $self->log_fatal(
         "no license data in config, no %Rights stash,",
-        "couldn't make a good guess at license from Pod; giving up"
+        "couldn't make a good guess at license from Pod; giving up. ",
+        "Perhaphs you need set global config file (dzil setup)?"
       );
     }
 
@@ -215,7 +248,7 @@ sub _build_license {
     $self->log("based on POD in $filename, guessing license is $guess[0]");
   }
 
-  Class::MOP::load_class($license_class);
+  Class::Load::load_class($license_class);
 
   my $license = $license_class->new({
     holder => $self->_copyright_holder,
@@ -280,7 +313,6 @@ has authors => (
   is   => 'ro',
   isa  => ArrayRef[Str],
   lazy => 1,
-  required => 1,
   default  => sub {
     my ($self) = @_;
 
@@ -358,13 +390,13 @@ sub _build_distmeta {
   my $meta = {
     'meta-spec' => {
       version => 2,
-      url     => 'http://github.com/dagolden/cpan-meta/',
+      url     => 'http://search.cpan.org/perldoc?CPAN::Meta::Spec',
     },
     name     => $self->name,
     version  => $self->version,
     abstract => $self->abstract,
     author   => $self->authors,
-    license  => $self->license->meta2_name,
+    license  => [ $self->license->meta2_name ],
 
     # XXX: what about unstable?
     release_status => ($self->is_trial or $self->version =~ /_/)
@@ -377,8 +409,15 @@ sub _build_distmeta {
                     . (defined $self->VERSION ? $self->VERSION : '(undef)')
   };
 
-  $meta = Hash::Merge::Simple::merge($meta, $_->metadata)
-    for $self->plugins_with(-MetaProvider)->flatten;
+  require Hash::Merge::Simple;
+  my $dynamic;
+  for ($self->plugins_with(-MetaProvider)->flatten) {
+    my $plugin_meta = $_->metadata;
+    $meta = Hash::Merge::Simple::merge($meta, $plugin_meta);
+    $dynamic = 1 if $plugin_meta->{dynamic_config};
+  }
+
+  $meta->{dynamic_config} = 1 if $dynamic;
 
   return $meta;
 }
@@ -461,15 +500,7 @@ sub _write_out_file {
 
   Carp::croak("attempted to write $to multiple times") if -e $to;
 
-  open my $out_fh, '>', "$to" or die "couldn't open $to to write: $!";
-
-  # This is needed, or \n is translated to \r\n on win32.
-  # Maybe :raw:utf8 is needed, but not sure.
-  #     -- Kentnl - 2010-06-10
-  binmode( $out_fh , ":raw" );
-
-  print { $out_fh } $file->content;
-  close $out_fh or die "error closing $to: $!";
+  path("$to")->spew_raw( $file->encoded_content );
   chmod $file->mode, "$to" or die "couldn't chmod $to: $!";
 }
 
@@ -516,17 +547,19 @@ sub stash_named {
 __PACKAGE__->meta->make_immutable;
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla - distribution builder; installer not included!
 
 =head1 VERSION
 
-version 4.300020
+version 5.008
 
 =head1 DESCRIPTION
 
@@ -722,7 +755,7 @@ L<GatherDir|Dist::Zilla::Plugin::GatherDir>,
 L<Prereqs|Dist::Zilla::Plugin::Prereqs>,
 L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>,
 L<MetaYAML|Dist::Zilla::Plugin::MetaYAML>,
-L<MetaYAML|Dist::Zilla::Plugin::MetaJSON>,
+L<MetaJSON|Dist::Zilla::Plugin::MetaJSON>,
 ...
 
 =back
@@ -751,10 +784,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
