@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::listdeps;
 {
-  $Dist::Zilla::App::Command::listdeps::VERSION = '4.300020';
+  $Dist::Zilla::App::Command::listdeps::VERSION = '5.008';
 }
 use Dist::Zilla::App -command;
 # ABSTRACT: print your distribution's prerequisites
@@ -15,21 +15,30 @@ sub abstract { "print your distribution's prerequisites" }
 sub opt_spec {
   [ 'author', 'include author dependencies' ],
   [ 'missing', 'list only the missing dependencies' ],
-  [ 'versions', 'include required version numbers in listing' ]
+  [ 'versions', 'include required version numbers in listing' ],
+  [ 'json', 'list dependencies by phase, in JSON format' ],
+}
+
+sub prereqs {
+  my ($self, $zilla) = @_;
+
+  $_->before_build for @{ $zilla->plugins_with(-BeforeBuild) };
+  $_->gather_files for @{ $zilla->plugins_with(-FileGatherer) };
+  $_->set_file_encodings for @{ $zilla->plugins_with(-EncodingProvider) };
+  $_->prune_files  for @{ $zilla->plugins_with(-FilePruner) };
+  $_->munge_files  for @{ $zilla->plugins_with(-FileMunger) };
+  $_->register_prereqs for @{ $zilla->plugins_with(-PrereqSource) };
+
+  my $prereqs = $zilla->prereqs;
 }
 
 sub extract_dependencies {
   my ($self, $zilla, $phases, $missing) = @_;
 
-  $_->before_build for @{ $zilla->plugins_with(-BeforeBuild) };
-  $_->gather_files for @{ $zilla->plugins_with(-FileGatherer) };
-  $_->prune_files  for @{ $zilla->plugins_with(-FilePruner) };
-  $_->munge_files  for @{ $zilla->plugins_with(-FileMunger) };
-  $_->register_prereqs for @{ $zilla->plugins_with(-PrereqSource) };
+  my $prereqs = $self->prereqs($zilla);
 
   require CPAN::Meta::Requirements;
   my $req = CPAN::Meta::Requirements->new;
-  my $prereqs = $zilla->prereqs;
 
   for my $phase (@$phases) {
     $req->add_requirements( $prereqs->requirements_for($phase, 'requires') );
@@ -66,10 +75,19 @@ sub execute {
   my @phases = qw(build test configure runtime);
   push @phases, 'develop' if $opt->author;
 
+  if($opt->json) {
+    my $prereqs = $self->prereqs($self->zilla);
+    my $output = $prereqs->as_string_hash;
+
+    require JSON; JSON->VERSION(2);
+    print JSON->new->ascii(1)->canonical(1)->pretty->encode($output), "\n";
+    return 1;
+  }
+
   my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing);
 
   if($opt->versions) {
-    for(sort { lc $a cmp $b } keys %modules) {
+    for(sort { lc $a cmp lc $b } keys %modules) {
       print "$_ = ".$modules{$_}."\n";
     }
   } else {
@@ -80,15 +98,18 @@ sub execute {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 4.300020
+version 5.008
 
 =head1 SYNOPSIS
 
@@ -98,14 +119,31 @@ version 4.300020
 
 This is a command plugin for L<Dist::Zilla>. It provides the C<listdeps>
 command, which prints your distribution's prerequisites. You could pipe that
-list to a CPAN client like L<cpan> to install all of the dependecies in one
-quick go. This will include author dependencies (those listed under
-C<develop_requires>) if the C<--author> flag is passed. You can also pass the
-C<--missing> flag to list only dependencies which are unsatisfied.
+list to a CPAN client like L<cpan> to install all of the dependencies in one
+quick go.
+
+=head1 OPTIONS
+
+=head2 --author
+
+Include author dependencies (those listed under C<develop_requires>).
+
+=head2 --missing
+
+List only dependencies which are unsatisfied.
+
+=head2 --versions
+
+Also display the required versions of listed modules.
+
+=head2 --json
+
+Lists all prerequisites in JSON format, as they would appear in META.json
+(broken out into phases and types)
 
 =head1 ACKNOWLEDGEMENTS
 
-This code is more or less a direct copy of Marcel Gruenauer (hanekomu)
+This code was originally more or less a direct copy of Marcel Gruenauer (hanekomu)
 Dist::Zilla::App::Command::prereqs, updated to work with the Dist::Zilla v2
 API.
 
@@ -115,10 +153,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
