@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::run;
 {
-  $Dist::Zilla::App::Command::run::VERSION = '4.300020';
+  $Dist::Zilla::App::Command::run::VERSION = '5.008';
 }
 # ABSTRACT: run stuff in a dir where your dist is built
 use Dist::Zilla::App -command;
@@ -10,12 +10,17 @@ use Dist::Zilla::App -command;
 
 sub abstract { 'run stuff in a dir where your dist is built' }
 
+sub opt_spec {
+  [ 'build!' => 'do the Build actions before running the command; done by default',
+                { default => 1 } ],
+}
+
 sub usage_desc {
-  return '%c %o [ run command [ arg1 arg2 ... ] ]';
+  return '%c run %o [ run command [ arg1 arg2 ... ] ]';
 }
 
 sub execute {
-  my ($self, $opts, $args) = @_;
+  my ($self, $opt, $args) = @_;
 
   unless (@$args) {
     my $envname = $^O eq 'MSWin32' ? 'COMSPEC' : 'SHELL';
@@ -26,21 +31,24 @@ sub execute {
     $self->log("no command supplied to run so using \$$envname: $args->[0]");
   }
 
-  $self->zilla->run_in_build($args);
+  $self->zilla->run_in_build($args, { build => $opt->build });
 }
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::run - run stuff in a dir where your dist is built
 
 =head1 VERSION
 
-version 4.300020
+version 5.008
 
 =head1 SYNOPSIS
 
@@ -78,10 +86,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
