@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Dist::Zilla::App::Command::test;
 {
-  $Dist::Zilla::App::Command::test::VERSION = '4.300020';
+  $Dist::Zilla::App::Command::test::VERSION = '5.008';
 }
 # ABSTRACT: test your dist
 use Dist::Zilla::App -command;
@@ -12,7 +12,8 @@ sub opt_spec {
   [ 'release'   => 'enables the RELEASE_TESTING env variable', { default => 0 } ],
   [ 'automated' => 'enables the AUTOMATED_TESTING env variable', { default => 0 } ],
   [ 'author!' => 'enables the AUTHOR_TESTING env variable (default behavior)', { default => 1 } ],
-  [ 'all' => 'enables the RELEASE_TESTING, AUTOMATED_TESTING and AUTHOR_TESTING env variables', { default => 0 } ]
+  [ 'all' => 'enables the RELEASE_TESTING, AUTOMATED_TESTING and AUTHOR_TESTING env variables', { default => 0 } ],
+  [ 'keep-build-dir|keep' => 'keep the build directory even after a success' ],
 }
 
 
@@ -25,21 +26,28 @@ sub execute {
   local $ENV{AUTHOR_TESTING} = 1 if $opt->author or $opt->all;
   local $ENV{AUTOMATED_TESTING} = 1 if $opt->automated or $opt->all;
 
-  $self->zilla->test;
+  $self->zilla->test({
+    $opt->keep_build_dir
+      ? (keep_build_dir => 1)
+      : (),
+  });
 }
 
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::test - test your dist
 
 =head1 VERSION
 
-version 4.300020
+version 5.008
 
 =head1 SYNOPSIS
 
@@ -86,10 +94,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
