@@ -1,6 +1,6 @@
 package Dist::Zilla::MVP::RootSection;
 {
-  $Dist::Zilla::MVP::RootSection::VERSION = '4.300020';
+  $Dist::Zilla::MVP::RootSection::VERSION = '5.008';
 }
 use Moose;
 extends 'Config::MVP::Section';
@@ -32,7 +32,19 @@ after finalize => sub {
 
   my $assembler = $self->sequence->assembler;
 
-  my $zilla = $assembler->zilla_class->new( $self->payload );
+  my %payload = %{ $self->payload };
+
+  my %dzil;
+  $dzil{$_} = delete $payload{":$_"} for grep { s/\A:// } keys %payload;
+
+  my $zilla = $assembler->zilla_class->new( \%payload );
+
+  if (defined $dzil{version}) {
+    Dist::Zilla::Util->_assert_loaded_class_version_ok(
+      'Dist::Zilla',
+      $dzil{version},
+    );
+  }
 
   $self->set_zilla($zilla);
 };
@@ -41,15 +53,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MVP::RootSection - a standard section in Dist::Zilla's configuration sequence
 
 =head1 VERSION
 
-version 4.300020
+version 5.008
 
 =head1 DESCRIPTION
 
@@ -82,10 +97,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
