@@ -1,6 +1,6 @@
 package Dist::Zilla::MintingProfile::Default;
 {
-  $Dist::Zilla::MintingProfile::Default::VERSION = '4.300005';
+  $Dist::Zilla::MintingProfile::Default::VERSION = '5.008';
 }
 # ABSTRACT: Default minting profile provider
 use Moose;
@@ -17,10 +17,13 @@ around profile_dir => sub {
 
   $profile_name ||= 'default';
 
-  my $profile_dir = Dist::Zilla::Util->_global_config_root
-                  ->subdir('profiles', $profile_name);
+  # shouldn't look in user's config when testing
+  if (!$ENV{DZIL_TESTING}) {
+    my $profile_dir = Dist::Zilla::Util->_global_config_root
+                    ->subdir('profiles', $profile_name);
 
-  return $profile_dir if -d $profile_dir;
+    return $profile_dir if -d $profile_dir;
+  }
 
   return $self->$orig($profile_name);
 };
@@ -29,15 +32,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::MintingProfile::Default - Default minting profile provider
 
 =head1 VERSION
 
-version 4.300005
+version 5.008
 
 =head1 DESCRIPTION
 
@@ -52,10 +58,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
