@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AutoPrereqs;
 {
-  $Dist::Zilla::Plugin::AutoPrereqs::VERSION = '4.300009';
+  $Dist::Zilla::Plugin::AutoPrereqs::VERSION = '5.008';
 }
 use Moose;
 with(
@@ -25,8 +25,9 @@ use namespace::autoclean;
 
 # ABSTRACT: automatically extract prereqs from your modules
 
+use List::AllUtils 'uniq';
 use Moose::Autobox;
-use Perl::PrereqScanner 1.005; # do not prune common libs
+use Perl::PrereqScanner 1.016; # don't skip "lib"
 use PPI;
 use CPAN::Meta::Requirements;
 use version;
@@ -78,16 +79,27 @@ sub register_prereqs {
     my $files = $self->$method;
 
     foreach my $file (@$files) {
+      # skip binary files
+      next if $file->is_bytes;
       # parse only perl files
-      next unless $file->name =~ /\.(?:pm|pl|t)$/i
+      next unless $file->name =~ /\.(?:pm|pl|t|psgi)$/i
                || $file->content =~ /^#!(?:.*)perl(?:$|\s)/;
+      # RT#76305 skip extra tests produced by ExtraTests plugin
+      next if $file->name =~ m{^t/(?:author|release)-[^/]*\.t$};
 
       # store module name, to trim it from require list later on
-      my $module = $file->name;
-      $module =~ s{^(?:t/)?lib/}{};
-      $module =~ s{\.pm$}{};
-      $module =~ s{/}{::}g;
-      push @modules, $module;
+      my @this_thing = $file->name;
+      if ($this_thing[0] =~ /^t/) {
+        push @this_thing, ($this_thing[0]) x 2;
+        $this_thing[1] =~ s{^t/}{};
+        $this_thing[2] =~ s{^t/lib/}{};
+      } else {
+        $this_thing[0] =~ s{^lib/}{};
+      }
+      @this_thing = uniq @this_thing;
+      s{\.pm$}{} for @this_thing;
+      s{/}{::}g for @this_thing;
+      push @modules, @this_thing;
 
       # parse a file, and merge with existing prereqs
       my $file_req = $scanner->scan_string($file->content);
@@ -98,6 +110,8 @@ sub register_prereqs {
     # remove prereqs shipped with current dist
     $req->clear_requirement($_) for @modules;
 
+    $req->clear_requirement($_) for qw(Config Errno); # never indexed
+
     # remove prereqs from skiplist
     for my $skip (($self->skips || [])->flatten) {
       my $re   = qr/$skip/;
@@ -125,15 +139,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::AutoPrereqs - automatically extract prereqs from your modules
 
 =head1 VERSION
 
-version 4.300009
+version 5.008
 
 =head1 SYNOPSIS
 
@@ -141,6 +158,7 @@ In your F<dist.ini>:
 
   [AutoPrereqs]
   skip = ^Foo|Bar$
+  skip = ^Other::Dist
 
 =head1 DESCRIPTION
 
@@ -148,7 +166,7 @@ This plugin will extract loosely your distribution prerequisites from
 your files using L<Perl::PrereqScanner>.
 
 If some prereqs are not found, you can still add them manually with the
-L<Dist::Zilla::Plugin::Prereqs> plugin.
+L<Prereqs|Dist::Zilla::Plugin::Prereqs> plugin.
 
 This plugin will skip the modules shipped within your dist.
 
@@ -186,8 +204,13 @@ of scanners.
 
 =head2 skips
 
-This is an arrayref of regular expressions.  Any module names matching
-any of these regex will not be registered as prerequisites.
+This is an arrayref of regular expressions, derived from all the 'skip' lines
+in the configuration.  Any module names matching any of these regexes will not
+be registered as prerequisites.
+
+=head1 SEE ALSO
+
+L<Prereqs|Dist::Zilla::Plugin::Prereqs>, L<Perl::PrereqScanner>.
 
 =head1 CREDITS
 
@@ -199,10 +222,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
