@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::InlineFiles;
 {
-  $Dist::Zilla::Plugin::InlineFiles::VERSION = '4.300005';
+  $Dist::Zilla::Plugin::InlineFiles::VERSION = '5.008';
 }
 # ABSTRACT: files in a data section
 use Moose;
@@ -11,9 +11,9 @@ use namespace::autoclean;
 
 
 use Sub::Exporter::ForMethods;
-use Data::Section 0.004 # fixed header_re
+use Data::Section 0.200002 # encoding and bytes
   { installer => Sub::Exporter::ForMethods::method_installer },
-  '-setup';
+  '-setup' => { encoding => 'bytes' };
 use Dist::Zilla::File::InMemory;
 
 sub gather_files {
@@ -38,15 +38,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::InlineFiles - files in a data section
 
 =head1 VERSION
 
-version 4.300005
+version 5.008
 
 =head1 DESCRIPTION
 
@@ -54,16 +57,22 @@ This plugin exists only to be extended, and gathers all files contained in its
 data section and those of its ancestors.  For more information, see
 L<Data::Section|Data::Section>.
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins inheriting from L<InlineFiles>:
+L<MetaTests|Dist::Zilla::Plugin::MetaTests>,
+L<PodCoverageTests|Dist::Zilla::Plugin::PodCoverageTests>,
+L<PodSyntaxTests|Dist::Zilla::Plugin::PodSyntaxTests>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
