@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::MetaJSON;
 {
-  $Dist::Zilla::Plugin::MetaJSON::VERSION = '4.300020';
+  $Dist::Zilla::Plugin::MetaJSON::VERSION = '5.008';
 }
 # ABSTRACT: produce a META.json
 use Moose;
@@ -9,11 +9,7 @@ with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
 
-use CPAN::Meta::Converter 2.101550; # improved downconversion
-use CPAN::Meta::Validator 2.101550; # improved downconversion
 use Dist::Zilla::File::FromCode;
-use Hash::Merge::Simple ();
-use JSON 2;
 
 
 has filename => (
@@ -34,8 +30,19 @@ sub gather_files {
 
   my $zilla = $self->zilla;
 
+  require JSON;
+  JSON->VERSION(2);
+  require CPAN::Meta::Converter;
+  CPAN::Meta::Converter->VERSION(2.101550); # improved downconversion
+  require CPAN::Meta::Validator;
+  CPAN::Meta::Validator->VERSION(2.101550); # improved downconversion
+
   my $file  = Dist::Zilla::File::FromCode->new({
     name => $self->filename,
+    # RJBS and XDG didn't 100% agree on this, it's probably fine until somebody
+    # comes up with a really good argument to change it (or to remove this
+    # comment, settling the argument). -- rjbs, 2013-10-19
+    code_return_type => 'bytes',
     code => sub {
       my $distmeta  = $zilla->distmeta;
 
@@ -62,17 +69,19 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 4.300020
+version 5.008
 
 =head1 DESCRIPTION
 
@@ -115,10 +124,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
