@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::PruneCruft;
 {
-  $Dist::Zilla::Plugin::PruneCruft::VERSION = '4.300010';
+  $Dist::Zilla::Plugin::PruneCruft::VERSION = '5.008';
 }
 # ABSTRACT: prune stuff that you probably don't mean to include
 use Moose;
@@ -72,15 +72,18 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PruneCruft - prune stuff that you probably don't mean to include
 
 =head1 VERSION
 
-version 4.300010
+version 5.008
 
 =head1 SYNOPSIS
 
@@ -99,16 +102,25 @@ can be specified multiple times):
   except = \.gitignore
   except = t/.*/\.keep$
 
+This plugin is included in the L<@Basic|Dist::Zilla::PluginBundle::Basic>
+bundle.
+
+=head1 SEE ALSO
+
+Dist::Zilla plugins:
+L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+L<PruneFiles|Dist::Zilla::Plugin::PruneFiles>,
+L<ManifestSkip|Dist::Zilla::Plugin::ManifestSkip>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
