@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::Basic;
 {
-  $Dist::Zilla::PluginBundle::Basic::VERSION = '4.300010';
+  $Dist::Zilla::PluginBundle::Basic::VERSION = '5.008';
 }
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
 use Moose;
@@ -34,16 +34,19 @@ sub configure {
 __PACKAGE__->meta->make_immutable;
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPAN dists
 
 =head1 VERSION
 
-version 4.300010
+version 5.008
 
 =head1 DESCRIPTION
 
@@ -113,20 +116,23 @@ L<Dist::Zilla::Plugin::UploadToCPAN>
 
 =back
 
+=head1 SEE ALSO
+
+Core Dist::Zilla plugins: L<@Filter|Dist::Zilla::PluginBundle::Filter>.
+
+Dist::Zilla roles:
+L<PluginBundle|Dist::Zilla::Role::PluginBundle>,
+L<PluginBundle::Easy|Dist::Zilla::Role::PluginBundle::Easy>.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
