@@ -1,13 +1,13 @@
 package Dist::Zilla::Tester;
 {
-  $Dist::Zilla::Tester::VERSION = '4.300034';
+  $Dist::Zilla::Tester::VERSION = '5.008';
 }
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
 # ABSTRACT: a testing-enabling stand-in for Dist::Zilla
 
 # XXX: Adding this autoclean causes problem.  "Builder" and "Minter" do not
-# show in in tests.  I'm really not sure why. -- rjbs, 2011-08-19
+# show in tests.  I'm really not sure why. -- rjbs, 2011-08-19
 # use namespace::autoclean;
 
 use autodie;
@@ -15,6 +15,7 @@ use Dist::Zilla::Chrome::Test;
 use File::pushd ();
 use File::Spec;
 use File::Temp;
+use Path::Tiny;
 
 use Sub::Exporter::Util ();
 use Sub::Exporter -setup => {
@@ -38,7 +39,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 {
   package Dist::Zilla::Tester::_Role;
 {
-  $Dist::Zilla::Tester::_Role::VERSION = '4.300034';
+  $Dist::Zilla::Tester::_Role::VERSION = '5.008';
 }
   use Moose::Role;
 
@@ -66,14 +67,17 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
   sub slurp_file {
     my ($self, $filename) = @_;
 
-    return scalar do {
-      local $/;
-      open my $fh, '<', $self->tempdir->file($filename);
+    Path::Tiny::path(
+      $self->tempdir->file($filename)
+    )->slurp_utf8;
+  }
 
-      # Win32.
-      binmode $fh, ':raw';
-      <$fh>;
-    };
+  sub slurp_file_raw {
+    my ($self, $filename) = @_;
+
+    Path::Tiny::path(
+      $self->tempdir->file($filename)
+    )->slurp_raw;
   }
 
   sub _metadata_generator_id { 'Dist::Zilla::Tester' }
@@ -84,7 +88,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 {
   package Dist::Zilla::Tester::_Builder;
 {
-  $Dist::Zilla::Tester::_Builder::VERSION = '4.300034';
+  $Dist::Zilla::Tester::_Builder::VERSION = '5.008';
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
@@ -126,13 +130,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
       while (my ($name, $content) = each %$files) {
         my $fn = $tempdir->file($name);
         $fn->dir->mkpath;
-        open my $fh, '>', $fn;
-
-        # Win32 fix for crlf translation.
-        #   maybe :raw:utf8? -- Kentnl - 2010-06-10
-        binmode $fh, ':raw';
-        print { $fh } $content;
-        close $fh;
+        Path::Tiny::path($fn)->spew_utf8($content);
       }
     }
 
@@ -180,7 +178,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 {
   package Dist::Zilla::Tester::_Minter;
 {
-  $Dist::Zilla::Tester::_Minter::VERSION = '4.300034';
+  $Dist::Zilla::Tester::_Minter::VERSION = '5.008';
 }
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
@@ -266,13 +264,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 4.300034
+version 5.008
 
 =head1 AUTHOR
 
